# Generated by Ansible

[k8sdc:children]
k8sdc-masters
k8sdc-nodes
etcd
fileserver

[k8sdc:vars]
ansible_private_key_file=keys/{{ ssh_key_name }}
ansible_user={{ do_admin_user }}

[k8sdc-masters]
{% for host in groups['k8sdc-masters'] %}
{{ host }} ansible_host={{ hostvars[host]['ansible_host'] }} 
{% endfor %}

[k8sdc-nodes]
{% for host in groups['k8sdc-nodes'] %}
{{ host }} ansible_host={{ hostvars[host]['ansible_host'] }} 
{% endfor %}

[etcd]
{% for host in groups['etcd'] %}
{{ host }} ansible_host={{ hostvars[host]['ansible_host'] }} 
{% endfor %}

[fileserver]
{% for host in groups['fileserver'] %}
{{ host }} ansible_host={{ hostvars[host]['ansible_host'] }} 
{% endfor %}